DiscoveredService

Struct DiscoveredService 

pub struct DiscoveredService {
    pub name: String,
    pub service_type: String,
    pub domain: String,
    pub host_name: String,
    pub port: u16,
    pub addresses: Vec<IpAddr>,
    pub txt_records: Vec<TxtRecord>,
    pub interface_index: Option<NonZeroU32>,
}
A resolved, connectable service instance.

Fields

name: String

The service instance name, e.g. My Web Server.

service_type: String

The service type, e.g. _http._tcp.

domain: String

The domain the service was discovered in, e.g. local.

host_name: String

The SRV target host name, e.g. macbook.local.

port: u16

The port the service accepts connections on.

addresses: Vec<IpAddr>

Resolved IP addresses for host_name. May be empty if address resolution did not (yet) yield any records.

txt_records: Vec<TxtRecord>

The service’s TXT record entries.

interface_index: Option<NonZeroU32>

The interface the service was discovered on, if known.

Implementations

Source

impl DiscoveredService

pub fn socket_addrs(&self) -> impl Iterator<Item = SocketAddr> + '_

Returns the resolved socket addresses (each address paired with the port).

pub fn txt(&self, key: &str) -> Option<&[u8]>

Returns the value of the first TXT record entry matching key, if any.

Returns Some(&[]) for a key that is present with an empty value and None for a key that is absent or key-only.